CREATE OR REPLACE PACKAGE BODY xlib_jasperreports
AS
   m_module       VARCHAR2 (50)   := 'XLIB_JASPERREPORTS';
   m_report_url   VARCHAR2 (4000);

----------------------------------------------------------------------------
-- set the URL for the report engine
----------------------------------------------------------------------------
   PROCEDURE set_report_url (
      p_report_url   IN   VARCHAR2
            DEFAULT 'http://localhost:8080/JasperReportIntegration/report'
   )
   IS
   BEGIN
      m_report_url := p_report_url;
   END;

----------------------------------------------------------------------------
-- make a callout with utl_http to the j2ee container running the
-- JasperReportsIntegration webapp
-- => return the results
----------------------------------------------------------------------------
   PROCEDURE show_report (
      p_rep_name            IN   VARCHAR2 DEFAULT 'test',
      p_rep_format          IN   VARCHAR2 DEFAULT 'pdf',
      p_data_source         IN   VARCHAR2 DEFAULT 'default',
      p_out_filename        IN   VARCHAR2 DEFAULT NULL,
      p_rep_locale          IN   VARCHAR2 DEFAULT 'de_DE',
      p_rep_encoding        IN   VARCHAR2 DEFAULT 'UTF-8',
      p_additional_params   IN   VARCHAR2 DEFAULT NULL
   )
   IS
      l_proc       VARCHAR2 (100)   := m_module || '.SHOW_REPORT';
      l_url        VARCHAR2 (32767);
      l_rep_name   VARCHAR2 (2000)  := p_rep_name;
   BEGIN
      -------------------------------------------------------
      -- mask rep_name, replace '/' with mask symbol '~'
      -------------------------------------------------------
      --l_rep_name := replace(l_rep_name, '/', '~');
      --l_rep_name := replace(l_rep_name, '\', '~');

      -------------------------------------------------------
      -- construct URL
      -------------------------------------------------------
      l_url := m_report_url;
      l_url := l_url || '?_repName=' || p_rep_name;
      l_url := l_url || '&_repFormat=' || p_rep_format;
      l_url := l_url || '&_dataSource=' || p_data_source;
      l_url := l_url || '&_outFilename=' || p_out_filename;
      l_url := l_url || '&_repLocale=' || p_rep_locale;
      l_url := l_url || '&_repEncoding=' || p_rep_encoding;

      IF (p_additional_params IS NOT NULL)
      THEN
         l_url := l_url || '&' || p_additional_params;
      END IF;

      -------------------------------------------------------
      -- call Tomcat
      -------------------------------------------------------
      xlib_http.display_url_raw (p_url => l_url);
   END;

----------------------------------------------------------------------------
-- make a callout with utl_http to the j2ee container running the
-- JasperReportsIntegration webapp
-- => return the report in a BLOB
----------------------------------------------------------------------------
   FUNCTION get_report (
      p_rep_name            IN   VARCHAR2 DEFAULT 'test',
      p_rep_format          IN   VARCHAR2 DEFAULT 'pdf',
      p_data_source         IN   VARCHAR2 DEFAULT 'default',
      p_out_filename        IN   VARCHAR2 DEFAULT NULL,
      p_rep_locale          IN   VARCHAR2 DEFAULT 'de_DE',
      p_rep_encoding        IN   VARCHAR2 DEFAULT 'UTF-8',
      p_additional_params   IN   VARCHAR2 DEFAULT NULL
   )
      RETURN BLOB
   IS
      l_proc        VARCHAR2 (100)   := m_module || '.SHOW_REPORT';
      l_url         VARCHAR2 (32767);
      l_rep_name    VARCHAR2 (2000)  := p_rep_name;
      l_blob        BLOB;
      l_mime_type   VARCHAR2 (100);
   BEGIN
      -------------------------------------------------------
      -- construct URL
      -------------------------------------------------------
      l_url := m_report_url;
      l_url := l_url || '?_repName=' || p_rep_name;
      l_url := l_url || '&_repFormat=' || p_rep_format;
      l_url := l_url || '&_dataSource=' || p_data_source;
      l_url := l_url || '&_outFilename=' || p_out_filename;
      l_url := l_url || '&_repLocale=' || p_rep_locale;
      l_url := l_url || '&_repEncoding=' || p_rep_encoding;

      IF (p_additional_params IS NOT NULL)
      THEN
         l_url := l_url || '&' || p_additional_params;
      END IF;

      -------------------------------------------------------
      -- call Tomcat
      -------------------------------------------------------
      xlib_http.retrieve_blob_from_url (p_url            => l_url,
                                        o_blob           => l_blob,
                                        o_mime_type      => l_mime_type
                                       );
      RETURN l_blob;
   END;
END;
/